Exception: FunctionExporter::NameError
- Inherits:
-
NameError
- Object
- NameError
- FunctionExporter::NameError
- Defined in:
- lib/function_importer.rb
Overview
raise this exception when method is not exist in a module.
raise this exception when method is not exist in a module.